# orkg-pypi
[![Documentation Status](https://readthedocs.org/projects/orkg/badge/?version=latest)](https://orkg.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/orkg.svg)](https://badge.fury.io/py/orkg)

A python client interacting with the ORKG API and sprinkling some python magic on top.

The package a implements many of the API calls described in the [documentation](http://tibhannover.gitlab.io/orkg/orkg-backend/api-doc/), and provides a set of extra features like graph pythonic objects and dynamic instantiation of entities from specifications.

You can find details about how-to use the package on [Read the Docs](https://orkg.readthedocs.io/en/latest/index.html).

Special thanks to **Allard Oelen** , **Kheir Eddine Farfar**, and **Omar Arab Oghli** for their contributions to the code.